@@ -1,6 +1,5 @@
 /*============================================================================
-
-  WCSLIB 7.1 - an implementation of the FITS WCS standard.
+  WCSLIB 7.3 - an implementation of the FITS WCS standard.
   Copyright (C) 1995-2020, Mark Calabretta
 
   This file is part of WCSLIB.
@@ -22,14 +21,14 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: log.c,v 7.1 2019/12/31 13:25:19 mcalabre Exp $
+  $Id: log.c,v 7.3.1.2 2020/08/17 11:19:09 mcalabre Exp mcalabre $
 *===========================================================================*/
 
 #include <math.h>
 
 #include "log.h"
 
-/* Map status return value to message. */
+// Map status return value to message.
 const char *log_errmsg[] = {
   "Success",
   "",
@@ -38,7 +37,7 @@ const char *log_errmsg[] = {
   "One or more of the world coordinates were invalid"};
 
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int logx2s(
   double crval,
@@ -71,7 +70,7 @@ int logx2s(
   return 0;
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int logs2x(
   double crval,
