@@ -1,6 +1,5 @@
 /*============================================================================
-
-  WCSLIB 7.1 - an implementation of the FITS WCS standard.
+  WCSLIB 7.3 - an implementation of the FITS WCS standard.
   Copyright (C) 1995-2020, Mark Calabretta
 
   This file is part of WCSLIB.
@@ -22,7 +21,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: prj_f.c,v 7.1 2019/12/31 13:25:19 mcalabre Exp $
+  $Id: prj_f.c,v 7.3.1.2 2020/08/17 11:21:34 mcalabre Exp mcalabre $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -32,7 +31,7 @@
 #include <wcsutil.h>
 #include <prj.h>
 
-/* Fortran name mangling (see below for the remainder). */
+// Fortran name mangling (see below for the remainder).
 #include <wcsconfig_f77.h>
 #define prjput_  F77_FUNC(prjput,  PRJPUT)
 #define prjptc_  F77_FUNC(prjptc,  PRJPTC)
@@ -49,7 +48,7 @@
 #define prjperr_ F77_FUNC(prjperr, PRJPERR)
 #define prjbchk_ F77_FUNC(prjbchk, PRJBCHK)
 
-/* Must match the values set in prj.inc. */
+// Must match the values set in prj.inc.
 #define PRJ_FLAG      100
 #define PRJ_CODE      101
 #define PRJ_R0        102
@@ -72,7 +71,7 @@
 #define PRJ_W         211
 #define PRJ_N         212
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int prjput_(int *prj, const int *what, const void *value, const int *m)
 
@@ -82,7 +81,7 @@ int prjput_(int *prj, const int *what, const void *value, const int *m)
   const double *dvalp;
   struct prjprm *prjp;
 
-  /* Cast pointers. */
+  // Cast pointers.
   prjp  = (struct prjprm *)prj;
   cvalp = (const char *)value;
   ivalp = (const int *)value;
@@ -93,7 +92,7 @@ int prjput_(int *prj, const int *what, const void *value, const int *m)
     prjp->flag = *ivalp;
     break;
   case PRJ_CODE:
-    /* Only three characters need be given. */
+    // Only three characters need be given.
     wcsutil_strcvt(3, ' ', cvalp, prjp->code);
     prjp->code[3] = '\0';
     wcsutil_null_fill(4, prjp->code);
@@ -140,7 +139,7 @@ int prjpti_(int *prj, const int *what, const int *value, const int *m)
   return prjput_(prj, what, value, m);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int prjget_(const int *prj, const int *what, void *value)
 
@@ -153,7 +152,7 @@ int prjget_(const int *prj, const int *what, void *value)
   const int *iprjp;
   const struct prjprm *prjp;
 
-  /* Cast pointers. */
+  // Cast pointers.
   prjp  = (const struct prjprm *)prj;
   cvalp = (char *)value;
   ivalp = (int *)value;
@@ -214,7 +213,7 @@ int prjget_(const int *prj, const int *what, void *value)
     *dvalp = prjp->y0;
     break;
   case PRJ_ERR:
-    /* Copy the contents of the wcserr struct. */
+    // Copy the contents of the wcserr struct.
     if (prjp->err) {
       iprjp = (int *)(prjp->err);
       for (l = 0; l < ERRLEN; l++) {
@@ -256,7 +255,7 @@ int prjgti_(const int *prj, const int *what, int *value)
   return prjget_(prj, what, value);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int prjini_(int *prj)
 
@@ -264,7 +263,7 @@ int prjini_(int *prj)
   return prjini((struct prjprm *)prj);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int prjfree_(int *prj)
 
@@ -272,23 +271,23 @@ int prjfree_(int *prj)
   return prjfree((struct prjprm *)prj);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int prjprt_(const int *prj)
 
 {
-  /* This may or may not force the Fortran I/O buffers to be flushed.  If
-   * not, try CALL FLUSH(6) before calling PRJPRT in the Fortran code. */
+  // This may or may not force the Fortran I/O buffers to be flushed.  If
+  // not, try CALL FLUSH(6) before calling PRJPRT in the Fortran code.
   fflush(NULL);
 
   return prjprt((const struct prjprm *)prj);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
-/* If null-terminated (using the Fortran CHAR(0) intrinsic), prefix may be of
- * length less than but not exceeding 72 and trailing blanks are preserved.
- * Otherwise, it must be of length 72 and trailing blanks are stripped off. */
+// If null-terminated (using the Fortran CHAR(0) intrinsic), prefix may be of
+// length less than but not exceeding 72 and trailing blanks are preserved.
+// Otherwise, it must be of length 72 and trailing blanks are stripped off.
 
 int prjperr_(int *prj, const char prefix[72])
 
@@ -298,14 +297,14 @@ int prjperr_(int *prj, const char prefix[72])
   wcsutil_strcvt(72, '\0', prefix, prefix_);
   prefix_[72] = '\0';
 
-  /* This may or may not force the Fortran I/O buffers to be flushed. */
-  /* If not, try CALL FLUSH(6) before calling PRJPERR in the Fortran code. */
+  // This may or may not force the Fortran I/O buffers to be flushed.
+  // If not, try CALL FLUSH(6) before calling PRJPERR in the Fortran code.
   fflush(NULL);
 
   return wcserr_prt(((struct prjprm *)prj)->err, prefix_);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int prjbchk_(
   const double *tol,
@@ -320,7 +319,7 @@ int prjbchk_(
   return prjbchk(*tol, *nphi, *ntheta, *spt, phi, theta, stat);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 #define PRJSET_FWRAP(pcode, PCODE) \
   int F77_FUNC(pcode##set, PCODE##SET)(int *prj) \
