@@ -1,6 +1,5 @@
 /*============================================================================
-
-  WCSLIB 7.1 - an implementation of the FITS WCS standard.
+  WCSLIB 7.3 - an implementation of the FITS WCS standard.
   Copyright (C) 1995-2020, Mark Calabretta
 
   This file is part of WCSLIB.
@@ -22,7 +21,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: spx_f.c,v 7.1 2019/12/31 13:25:19 mcalabre Exp $
+  $Id: spx_f.c,v 7.3.1.2 2020/08/17 11:21:34 mcalabre Exp mcalabre $
 *===========================================================================*/
 
 #include <string.h>
@@ -31,15 +30,15 @@
 #include <wcsutil.h>
 #include <spx.h>
 
-/* Fortran name mangling. */
+// Fortran name mangling.
 #include <wcsconfig_f77.h>
 #define spxget_ F77_FUNC(spxget, SPXGET)
 #define specx_  F77_FUNC(specx,  SPECX)
 
-/* Must match the value set in spx.inc. */
+// Must match the value set in spx.inc.
 #define SPX_ERR     200
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int spxget_(const int *spx, const int *what, void *value)
 
@@ -49,13 +48,13 @@ int spxget_(const int *spx, const int *what, void *value)
   const int *ispxp;
   const struct spxprm *spxp;
 
-  /* Cast pointers. */
+  // Cast pointers.
   spxp  = (const struct spxprm *)spx;
   ivalp = (int *)value;
 
   switch (*what) {
   case SPX_ERR:
-    /* Copy the contents of the wcserr struct. */
+    // Copy the contents of the wcserr struct.
     if (spxp->err) {
       ispxp = (int *)(spxp->err);
       for (l = 0; l < ERRLEN; l++) {
@@ -79,7 +78,7 @@ int spxgti_(const int *spx, const int *what, int *value)
   return spxget_(spx, what, value);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int specx_(
   const char   type[4],
@@ -97,7 +96,7 @@ int specx_(
   return specx(type_, *spec, *restfrq, *restwav, (struct spxprm *)specs);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 #define SPX_FWRAP(scode, SCODE) \
   int F77_FUNC(scode, SCODE)( \
