@@ -1,6 +1,6 @@
 *=======================================================================
 *
-* WCSLIB 7.1 - an implementation of the FITS WCS standard.
+* WCSLIB 7.3 - an implementation of the FITS WCS standard.
 * Copyright (C) 1995-2020, Mark Calabretta
 *
 * This file is part of WCSLIB.
@@ -22,7 +22,7 @@
 *
 * Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
 * http://www.atnf.csiro.au/people/Mark.Calabretta
-* $Id: tdis1.f,v 7.1 2019/12/31 13:25:19 mcalabre Exp $
+* $Id: tdis1.f,v 7.3.1.1 2020/06/03 03:38:11 mcalabre Exp mcalabre $
 *=======================================================================
 
       PROGRAM TDIS1
@@ -140,7 +140,7 @@
       END IF
 
 *     Henceforth, we will work with linprm.  Make a shallow copy.
-      STATUS = WCSGET (WCS, WCS_LIN, LIN)
+      STATUS = WCSGTI (WCS, WCS_LIN, LIN)
       IF (STATUS.NE.0) THEN
         STATUS = WCSPERR (WCS, CHAR(0))
         GO TO 999
