@@ -1,6 +1,6 @@
 *=======================================================================
 *
-* WCSLIB 7.1 - an implementation of the FITS WCS standard.
+* WCSLIB 7.3 - an implementation of the FITS WCS standard.
 * Copyright (C) 1995-2020, Mark Calabretta
 *
 * This file is part of WCSLIB.
@@ -22,7 +22,7 @@
 *
 * Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
 * http://www.atnf.csiro.au/people/Mark.Calabretta
-* $Id: tprj1.f,v 7.1 2019/12/31 13:25:19 mcalabre Exp $
+* $Id: tprj1.f,v 7.3.1.1 2020/06/03 03:38:11 mcalabre Exp mcalabre $
 *=======================================================================
 
       PROGRAM TPRJ1
@@ -230,15 +230,15 @@
       STATUS = PRJINI(PRJ)
 
       DO 10 J = 0, 29
-        STATUS = PRJPUT (PRJ, PRJ_PV, PV(J), J)
+        STATUS = PRJPTD (PRJ, PRJ_PV, PV(J), J)
  10   CONTINUE
 
 *     N.B. special case - only three characters need be given.
-      STATUS = PRJPUT (PRJ, PRJ_CODE, PCODE, 0)
+      STATUS = PRJPTC (PRJ, PRJ_CODE, PCODE, 0)
 
 *     Uncomment the next line to test alternative initializations of
 *     projection parameters.
-*     STATUS = PRJPUT (PRJ, PRJ_R0, 180D0/PI, 0)
+*     STATUS = PRJPTD (PRJ, PRJ_R0, 180D0/PI, 0)
 
       WRITE (*, 20) PCODE, NORTH, SOUTH, TOL
  20   FORMAT ('Testing ',A3,'; latitudes',I3,' to',I4,
