@@ -1,6 +1,6 @@
 *=======================================================================
 *
-* WCSLIB 7.1 - an implementation of the FITS WCS standard.
+* WCSLIB 7.3 - an implementation of the FITS WCS standard.
 * Copyright (C) 1995-2020, Mark Calabretta
 *
 * This file is part of WCSLIB.
@@ -22,7 +22,7 @@
 *
 * Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
 * http://www.atnf.csiro.au/people/Mark.Calabretta
-* $Id: ttab3.f,v 7.1 2019/12/31 13:25:19 mcalabre Exp $
+* $Id: ttab3.f,v 7.3.1.1 2020/06/03 03:38:11 mcalabre Exp mcalabre $
 *=======================================================================
 
       PROGRAM TTAB3
@@ -85,7 +85,7 @@
 
 
 *     Set up the lookup table.
-      STATUS = TABPUT (TAB, TAB_FLAG, -1, 0, 0)
+      STATUS = TABPTI (TAB, TAB_FLAG, -1, 0, 0)
       STATUS = TABINI(M, K, TAB)
       IF (STATUS.NE.0) THEN
         WRITE (*, 20) STATUS
@@ -93,14 +93,14 @@
         GO TO 999
       END IF
 
-      STATUS = TABPUT (TAB, TAB_M, M, 0, 0)
+      STATUS = TABPTI (TAB, TAB_M, M, 0, 0)
       DO 40 IM = 1, M
-        STATUS = TABPUT (TAB, TAB_K,     K(IM),     IM, 0)
-        STATUS = TABPUT (TAB, TAB_MAP,   MAP(IM),   IM, 0)
-        STATUS = TABPUT (TAB, TAB_CRVAL, CRVAL(IM), IM, 0)
+        STATUS = TABPTI (TAB, TAB_K,     K(IM),     IM, 0)
+        STATUS = TABPTI (TAB, TAB_MAP,   MAP(IM),   IM, 0)
+        STATUS = TABPTD (TAB, TAB_CRVAL, CRVAL(IM), IM, 0)
 
         DO 30 IK = 1, K(IM)
-          STATUS = TABPUT (TAB, TAB_INDEX, DBLE(IK-1), IM, IK)
+          STATUS = TABPTD (TAB, TAB_INDEX, DBLE(IK-1), IM, IK)
  30     CONTINUE
  40   CONTINUE
 
@@ -127,8 +127,8 @@
       IK = 1
       DO 80 J = 1, K2
         DO 70 I = 1, K1
-          STATUS = TABPUT (TAB, TAB_COORD, COORD(1,I,J), IK, 0)
-          STATUS = TABPUT (TAB, TAB_COORD, COORD(2,I,J), IK+1, 0)
+          STATUS = TABPTD (TAB, TAB_COORD, COORD(1,I,J), IK, 0)
+          STATUS = TABPTD (TAB, TAB_COORD, COORD(2,I,J), IK+1, 0)
           IK = IK + 2
  70     CONTINUE
  80   CONTINUE
