@@ -1,6 +1,5 @@
 /*============================================================================
-
-  WCSLIB 7.1 - an implementation of the FITS WCS standard.
+  WCSLIB 7.3 - an implementation of the FITS WCS standard.
   Copyright (C) 1995-2020, Mark Calabretta
 
   This file is part of WCSLIB.
@@ -22,7 +21,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcs_f.c,v 7.1 2019/12/31 13:25:19 mcalabre Exp $
+  $Id: wcs_f.c,v 7.3.1.2 2020/08/17 11:21:34 mcalabre Exp mcalabre $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -34,7 +33,7 @@
 #include <wcsutil.h>
 #include <wcs.h>
 
-/* Fortran name mangling. */
+// Fortran name mangling.
 #include <wcsconfig_f77.h>
 #define wcsput_  F77_FUNC(wcsput,  WCSPUT)
 #define wcsptc_  F77_FUNC(wcsptc,  WCSPTC)
@@ -63,7 +62,7 @@
 #define wcscopy_ F77_FUNC(wcscopy, WCSCOPY)
 #define wcslib_version_ F77_FUNC(wcslib_version, WCSLIB_VERSION)
 
-/* Must match the value set in wcs.inc. */
+// Must match the value set in wcs.inc.
 #define WCS_FLAG     100
 #define WCS_NAXIS    101
 #define WCS_CRPIX    102
@@ -161,7 +160,7 @@
 #define WCS_SPC      213
 #define WCS_ERR      214
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcsput_(
   int *wcs,
@@ -177,13 +176,13 @@ int wcsput_(
   const double *dvalp;
   struct wcsprm *wcsp;
 
-  /* Cast pointers. */
+  // Cast pointers.
   wcsp  = (struct wcsprm *)wcs;
   cvalp = (const char *)value;
   ivalp = (const int *)value;
   dvalp = (const double *)value;
 
-  /* Convert 1-relative FITS axis numbers to 0-relative C array indices. */
+  // Convert 1-relative FITS axis numbers to 0-relative C array indices.
   i0 = *i - 1;
   j0 = *j - 1;
 
@@ -473,7 +472,7 @@ int wcspti_(int *wcs, const int *what, const int *value, const int *i,
   return wcsput_(wcs, what, value, i, j);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcsget_(const int *wcs, const int *what, void *value)
 
@@ -487,7 +486,7 @@ int wcsget_(const int *wcs, const int *what, void *value)
   const double *dwcsp;
   const struct wcsprm *wcsp;
 
-  /* Cast pointers. */
+  // Cast pointers.
   wcsp  = (const struct wcsprm *)wcs;
   cvalp = (char *)value;
   ivalp = (int *)value;
@@ -508,7 +507,7 @@ int wcsget_(const int *wcs, const int *what, void *value)
     }
     break;
   case WCS_PC:
-    /* C row-major to FORTRAN column-major. */
+    // C row-major to FORTRAN column-major.
     for (j = 0; j < naxis; j++) {
       dwcsp = wcsp->pc + j;
       for (i = 0; i < naxis; i++) {
@@ -580,7 +579,7 @@ int wcsget_(const int *wcs, const int *what, void *value)
     }
     break;
   case WCS_CD:
-    /* C row-major to FORTRAN column-major. */
+    // C row-major to FORTRAN column-major.
     for (j = 0; j < naxis; j++) {
       dwcsp = wcsp->cd + j;
       for (i = 0; i < naxis; i++) {
@@ -811,28 +810,28 @@ int wcsget_(const int *wcs, const int *what, void *value)
     }
     break;
   case WCS_LIN:
-    /* Copy the contents of the linprm struct. */
+    // Copy the contents of the linprm struct.
     iwcsp = (int *)(&(wcsp->lin));
     for (l = 0; l < LINLEN; l++) {
       *(ivalp++) = *(iwcsp++);
     }
     break;
   case WCS_CEL:
-    /* Copy the contents of the celprm struct. */
+    // Copy the contents of the celprm struct.
     iwcsp = (int *)(&(wcsp->cel));
     for (l = 0; l < CELLEN; l++) {
       *(ivalp++) = *(iwcsp++);
     }
     break;
   case WCS_SPC:
-    /* Copy the contents of the spcprm struct. */
+    // Copy the contents of the spcprm struct.
     iwcsp = (int *)(&(wcsp->spc));
     for (l = 0; l < SPCLEN; l++) {
       *(ivalp++) = *(iwcsp++);
     }
     break;
   case WCS_ERR:
-    /* Copy the contents of the wcserr struct. */
+    // Copy the contents of the wcserr struct.
     if (wcsp->err) {
       iwcsp = (int *)(wcsp->err);
       for (l = 0; l < ERRLEN; l++) {
@@ -866,12 +865,12 @@ int wcsgti_(const int *wcs, const int *what, int *value)
   return wcsget_(wcs, what, value);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcsnpv_(int *npvmax) { return wcsnpv(*npvmax); }
 int wcsnps_(int *npsmax) { return wcsnps(*npsmax); }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcsini_(const int *naxis, int *wcs)
 
@@ -879,7 +878,7 @@ int wcsini_(const int *naxis, int *wcs)
   return wcsini(1, *naxis, (struct wcsprm *)wcs);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcsinit_(
   const int *naxis,
@@ -892,7 +891,7 @@ int wcsinit_(
   return wcsinit(1, *naxis, (struct wcsprm *)wcs, *npvmax, *npsmax, *ndpmax);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcssub_(const int *wcssrc, int *nsub, int axes[], int *wcsdst)
 
@@ -901,7 +900,7 @@ int wcssub_(const int *wcssrc, int *nsub, int axes[], int *wcsdst)
                 (struct wcsprm *)wcsdst);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcscompare_(
   const int *cmp,
@@ -915,7 +914,7 @@ int wcscompare_(
                     (const struct wcsprm *)wcs2, equal);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcsfree_(int *wcs)
 
@@ -923,23 +922,23 @@ int wcsfree_(int *wcs)
   return wcsfree((struct wcsprm *)wcs);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcsprt_(const int *wcs)
 
 {
-  /* This may or may not force the Fortran I/O buffers to be flushed.  If
-   * not, try CALL FLUSH(6) before calling WCSPRT in the Fortran code. */
+  // This may or may not force the Fortran I/O buffers to be flushed.  If
+  // not, try CALL FLUSH(6) before calling WCSPRT in the Fortran code.
   fflush(NULL);
 
   return wcsprt((const struct wcsprm *)wcs);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
-/* If null-terminated (using the Fortran CHAR(0) intrinsic), prefix may be of
- * length less than but not exceeding 72 and trailing blanks are preserved.
- * Otherwise, it must be of length 72 and trailing blanks are stripped off. */
+// If null-terminated (using the Fortran CHAR(0) intrinsic), prefix may be of
+// length less than but not exceeding 72 and trailing blanks are preserved.
+// Otherwise, it must be of length 72 and trailing blanks are stripped off.
 
 int wcsperr_(int *wcs, const char prefix[72])
 
@@ -949,14 +948,14 @@ int wcsperr_(int *wcs, const char prefix[72])
   wcsutil_strcvt(72, '\0', prefix, prefix_);
   prefix_[72] = '\0';
 
-  /* This may or may not force the Fortran I/O buffers to be flushed. */
-  /* If not, try CALL FLUSH(6) before calling WCSPERR in the Fortran code. */
+  // This may or may not force the Fortran I/O buffers to be flushed.
+  // If not, try CALL FLUSH(6) before calling WCSPERR in the Fortran code.
   fflush(NULL);
 
   return wcsperr((struct wcsprm *)wcs, prefix_);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcsbchk_(int *wcs, int *bounds)
 
@@ -964,7 +963,7 @@ int wcsbchk_(int *wcs, int *bounds)
   return wcsbchk((struct wcsprm *)wcs, *bounds);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcsset_(int *wcs)
 
@@ -972,7 +971,7 @@ int wcsset_(int *wcs)
   return wcsset((struct wcsprm *)wcs);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcsp2s_(
   int *wcs,
@@ -990,7 +989,7 @@ int wcsp2s_(
                 theta, world, stat);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcss2p_(
   int* wcs,
@@ -1008,7 +1007,7 @@ int wcss2p_(
                 imgcrd, pixcrd, stat);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcsmix_(
   int *wcs,
@@ -1028,7 +1027,7 @@ int wcsmix_(
                 *viter, world, phi, theta, imgcrd, pixcrd);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcssptr_(
   struct wcsprm *wcs,
@@ -1048,7 +1047,7 @@ int wcssptr_(
   return status;
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int wcscopy_(
   const int *wcssrc,
@@ -1058,7 +1057,7 @@ int wcscopy_(
   return wcscopy(1, (const struct wcsprm *)wcssrc, (struct wcsprm *)wcsdst);
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 void wcslib_version_(
   char *wcsver,
