@@ -1,6 +1,5 @@
 /*============================================================================
-
-  PGSBOX 7.1 - draw curvilinear coordinate axes for PGPLOT.
+  PGSBOX 7.3 - draw curvilinear coordinate axes for PGPLOT.
   Copyright (C) 1997-2020, Mark Calabretta
 
   This file is part of PGSBOX.
@@ -22,7 +21,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: cpgsbox.h,v 7.1 2019/12/31 13:25:20 mcalabre Exp $
+  $Id: cpgsbox.h,v 7.3.1.2 2020/08/17 11:24:44 mcalabre Exp mcalabre $
 *=============================================================================
 *
 * cpgsbox() and cpglbox() are C wrappers for PGSBOX and PGLBOX.  Refer to the
@@ -108,4 +107,4 @@ void cpglbox(
 }
 #endif
 
-#endif /* PGSBOX_CPGSBOX */
+#endif // PGSBOX_CPGSBOX
