@@ -1,6 +1,6 @@
 *=======================================================================
 *
-* PGSBOX 7.1 - draw curvilinear coordinate axes for PGPLOT.
+* PGSBOX 7.3 - draw curvilinear coordinate axes for PGPLOT.
 * Copyright (C) 1997-2020, Mark Calabretta
 *
 * This file is part of PGSBOX.
@@ -22,7 +22,7 @@
 *
 * Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
 * http://www.atnf.csiro.au/people/Mark.Calabretta
-* $Id: pgtest.f,v 7.1 2019/12/31 13:25:20 mcalabre Exp $
+* $Id: pgtest.f,v 7.3.1.1 2020/06/03 03:38:11 mcalabre Exp mcalabre $
 *=======================================================================
       PROGRAM PGTEST
 *=======================================================================
@@ -106,7 +106,7 @@
       CALL PGASK (.TRUE.)
       CALL PGPAGE ()
 
-      STATUS = WCSPUT (WCS, WCS_FLAG, -1, 0, 0)
+      STATUS = WCSPTI (WCS, WCS_FLAG, -1, 0, 0)
 
 *-----------------------------------------------------------------------
 
@@ -331,26 +331,26 @@
 *     Set projection type to SIN.
       CTYPE(1) = 'RA---SIN'
       CTYPE(2) = 'DEC--SIN'
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
 
 *     Reference pixel coordinates.
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 384D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 256D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 384D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 256D0, 2, 0)
 
 *     Coordinate increments.
-      STATUS = WCSPUT (WCS, WCS_CDELT, -1D0/3600000D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CDELT,  1D0/3600000D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT, -1D0/3600000D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT,  1D0/3600000D0, 2, 0)
 
 *     Spherical coordinate references.
       DEC0 = -89.99995D0
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 25D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRVAL, DEC0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 25D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, DEC0, 2, 0)
 
 *     Set parameters for an NCP projection.
       DEC0 = DEC0*D2R
-      STATUS = WCSPUT (WCS, WCS_PV, 0D0, 2, 1)
-      STATUS = WCSPUT (WCS, WCS_PV, COS(DEC0)/SIN(DEC0), 2, 2)
+      STATUS = WCSPTD (WCS, WCS_PV, 0D0, 2, 1)
+      STATUS = WCSPTD (WCS, WCS_PV, COS(DEC0)/SIN(DEC0), 2, 2)
 
 *     Annotation.
       IDENTS(1) = 'Right ascension'
@@ -409,25 +409,25 @@
 *     Set projection type to conic equal-area.
       CTYPE(1) = 'RA---COE'
       CTYPE(2) = 'DEC--COE'
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
 
 *     Reference pixel coordinates.
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 256D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 256D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 256D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 256D0, 2, 0)
 
 *     Coordinate increments.
-      STATUS = WCSPUT (WCS, WCS_CDELT, -1D0/3D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CDELT,  1D0/3D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT, -1D0/3D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT,  1D0/3D0, 2, 0)
 
 *     Spherical coordinate references.
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 90D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 30D0, 2, 0)
-      STATUS = WCSPUT (WCS, WCS_LONPOLE, 150D0, 0, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 90D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 30D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_LONPOLE, 150D0, 0, 0)
 
 *     Middle latitude and offset from standard parallels.
-      STATUS = WCSPUT (WCS, WCS_PV, 60D0, 2, 1)
-      STATUS = WCSPUT (WCS, WCS_PV, 15D0, 2, 2)
+      STATUS = WCSPTD (WCS, WCS_PV, 60D0, 2, 1)
+      STATUS = WCSPTD (WCS, WCS_PV, 15D0, 2, 2)
 
 *     Annotation.
       IDENTS(1) = 'longitude'
@@ -475,10 +475,10 @@
      :  IC, CACHE, IERR)
 
 *     Set parameters to draw the native grid.
-      STATUS = WCSPUT (WCS, WCS_CRVAL,  0D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 60D0, 2, 0)
-      STATUS = WCSPUT (WCS, WCS_LONPOLE, 999D0, 0, 0)
-      STATUS = WCSPUT (WCS, WCS_LATPOLE, 999D0, 0, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL,  0D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 60D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_LONPOLE, 999D0, 0, 0)
+      STATUS = WCSPTD (WCS, WCS_LATPOLE, 999D0, 0, 0)
 
 *     We just want to delineate the boundary, in green.
       CALL PGSCI (7)
@@ -531,28 +531,28 @@
 *     Set projection type to polyconic.
       CTYPE(1) = 'RA---PCO'
       CTYPE(2) = 'DEC--PCO'
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
 
 *     Reference pixel coordinates.
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 192D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 640D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 192D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 640D0, 2, 0)
 
 *     Rotate 30 degrees.
       ROTN = 30D0*D2R
-      STATUS = WCSPUT (WCS, WCS_PC,  COS(ROTN), 1, 1)
-      STATUS = WCSPUT (WCS, WCS_PC,  SIN(ROTN), 1, 2)
-      STATUS = WCSPUT (WCS, WCS_PC, -SIN(ROTN), 2, 1)
-      STATUS = WCSPUT (WCS, WCS_PC,  COS(ROTN), 2, 2)
+      STATUS = WCSPTD (WCS, WCS_PC,  COS(ROTN), 1, 1)
+      STATUS = WCSPTD (WCS, WCS_PC,  SIN(ROTN), 1, 2)
+      STATUS = WCSPTD (WCS, WCS_PC, -SIN(ROTN), 2, 1)
+      STATUS = WCSPTD (WCS, WCS_PC,  COS(ROTN), 2, 2)
 
 *     Coordinate increments.
-      STATUS = WCSPUT (WCS, WCS_CDELT, -1D0/5D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CDELT,  1D0/5D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT, -1D0/5D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT,  1D0/5D0, 2, 0)
 
 *     Spherical coordinate references.
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 332D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRVAL,  40D0, 2, 0)
-      STATUS = WCSPUT (WCS, WCS_LONPOLE, -30D0, 0, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 332D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL,  40D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_LONPOLE, -30D0, 0, 0)
 
 *     Annotation.
       IDENTS(1) = 'Hour angle'
@@ -693,9 +693,9 @@
       GRID1(2) =  180D0
       GRID2(1) = -999D0
 
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 0D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 0D0, 2, 0)
-      STATUS = WCSPUT (WCS, WCS_LONPOLE, 999D0, 0, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 0D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 0D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_LONPOLE, 999D0, 0, 0)
 
       IC = -1
       CALL PGSBOX (BLC, TRC, IDENTS, OPT, -1, 0, C0, GCODE, 0D0, 2,
@@ -751,27 +751,27 @@
 *     Set projection type to plate carree.
       CTYPE(1) = 'GLON-CAR'
       CTYPE(2) = 'GLAT-CAR'
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
 
 *     Reference pixel coordinates.
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 226D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRPIX,  46D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 226D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX,  46D0, 2, 0)
 
 *     Linear transformation matrix.
       ROTN = 15D0*D2R
-      STATUS = WCSPUT (WCS, WCS_PC,  COS(ROTN), 1, 1)
-      STATUS = WCSPUT (WCS, WCS_PC,  SIN(ROTN), 1, 2)
-      STATUS = WCSPUT (WCS, WCS_PC, -SIN(ROTN), 2, 1)
-      STATUS = WCSPUT (WCS, WCS_PC,  COS(ROTN), 2, 2)
+      STATUS = WCSPTD (WCS, WCS_PC,  COS(ROTN), 1, 1)
+      STATUS = WCSPTD (WCS, WCS_PC,  SIN(ROTN), 1, 2)
+      STATUS = WCSPTD (WCS, WCS_PC, -SIN(ROTN), 2, 1)
+      STATUS = WCSPTD (WCS, WCS_PC,  COS(ROTN), 2, 2)
 
 *     Coordinate increments.
-      STATUS = WCSPUT (WCS, WCS_CDELT, -1D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CDELT,  1D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT, -1D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT,  1D0, 2, 0)
 
 *     Set parameters to draw the native grid.
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 0D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 0D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 0D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 0D0, 2, 0)
 
 *     The reference pixel was defined so that the native longitude runs
 *     from 225 deg to 45 deg and this will cause the grid to be
@@ -815,13 +815,13 @@
      :  NLDPRM, 256, IC, CACHE, IERR)
 
 *     Reset CRPIX previously modified by CYLFIX.
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 226D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRPIX,  46D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 226D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX,  46D0, 2, 0)
 
 *     Galactic reference coordinates.
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 30D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 35D0, 2, 0)
-      STATUS = WCSPUT (WCS, WCS_LONPOLE, 999D0, 0, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 30D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 35D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_LONPOLE, 999D0, 0, 0)
 
       CALL CYLFIX (NAXIS, WCS)
 
@@ -900,20 +900,20 @@
 *     Set projection type to plate carree.
       CTYPE(1) = 'RA---CAR'
       CTYPE(2) = 'DEC--CAR'
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
 
 *     Reference pixel coordinates.
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 0D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 0D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 0D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 0D0, 2, 0)
 
 *     Coordinate increments.
-      STATUS = WCSPUT (WCS, WCS_CDELT, -1D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CDELT,  1D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT, -1D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT,  1D0, 2, 0)
 
 *     Set parameters to draw the native grid.
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 0D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 0D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 0D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 0D0, 2, 0)
 
 *     Annotation.
       IDENTS(1) = 'Right ascension'
@@ -974,25 +974,25 @@
 *     Set projection type to cylindrical perspective.
       CTYPE(1) = 'RA---CYP'
       CTYPE(2) = 'DEC--CYP'
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
 
 *     Reference pixel coordinates.
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 0D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 0D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 0D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 0D0, 2, 0)
 
 *     Coordinate increments.
-      STATUS = WCSPUT (WCS, WCS_CDELT, -1D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CDELT,  1D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT, -1D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT,  1D0, 2, 0)
 
 *     Set parameters to draw the native grid.
-      STATUS = WCSPUT (WCS, WCS_CRVAL,  45D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRVAL, -90D0, 2, 0)
-      STATUS = WCSPUT (WCS, WCS_LONPOLE, 999D0, 0, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL,  45D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, -90D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_LONPOLE, 999D0, 0, 0)
 
 *     mu and lambda projection parameters.
-      STATUS = WCSPUT (WCS, WCS_PV, 0D0, 2, 1)
-      STATUS = WCSPUT (WCS, WCS_PV, 1D0, 2, 2)
+      STATUS = WCSPTD (WCS, WCS_PV, 0D0, 2, 1)
+      STATUS = WCSPTD (WCS, WCS_PV, 1D0, 2, 2)
 
 *     Annotation.
       IDENTS(1) = 'Right ascension'
@@ -1053,21 +1053,21 @@
 *     Set projection type to gnomonic.
       CTYPE(1) = 'RA---TAN'
       CTYPE(2) = 'DEC--TAN'
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
 
 *     Reference pixel coordinates.
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 50.5D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRPIX,  1.0D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 50.5D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX,  1.0D0, 2, 0)
 
 *     Coordinate increments.
-      STATUS = WCSPUT (WCS, WCS_CDELT, 1D-3, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CDELT, 1D-3, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT, 1D-3, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT, 1D-3, 2, 0)
 
 *     Set parameters to draw the native grid.
-      STATUS = WCSPUT (WCS, WCS_CRVAL, -45.0D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRVAL, -89.7D0, 2, 0)
-      STATUS = WCSPUT (WCS, WCS_LONPOLE, 999D0, 0, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, -45.0D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, -89.7D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_LONPOLE, 999D0, 0, 0)
 
 *     Annotation.
       IDENTS(1) = 'Right ascension'
@@ -1284,20 +1284,20 @@
 
       CTYPE(1) = 'X'
       CTYPE(2) = 'Y'
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(1), 1, 0)
+      STATUS = WCSPTC (WCS, WCS_CTYPE, CTYPE(2), 2, 0)
 
 *     Reference pixel coordinates.
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 2D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRPIX, 2D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 2D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRPIX, 2D0, 2, 0)
 
 *     Coordinate increments.
-      STATUS = WCSPUT (WCS, WCS_CDELT, 1D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CDELT, 1D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT, 1D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CDELT, 1D0, 2, 0)
 
 *     Spherical coordinate references.
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 2D0, 1, 0)
-      STATUS = WCSPUT (WCS, WCS_CRVAL, 2D0, 2, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 2D0, 1, 0)
+      STATUS = WCSPTD (WCS, WCS_CRVAL, 2D0, 2, 0)
 
 *     Annotation.
       IDENTS(1) = 'X'
