@@ -1,6 +1,5 @@
 /*============================================================================
-
-  WCSLIB 7.1 - an implementation of the FITS WCS standard.
+  WCSLIB 7.3 - an implementation of the FITS WCS standard.
   Copyright (C) 1995-2020, Mark Calabretta
 
   This file is part of WCSLIB.
@@ -22,7 +21,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: fitshdr.c,v 7.1 2019/12/31 13:25:20 mcalabre Exp $
+  $Id: fitshdr.c,v 7.3.1.2 2020/08/17 11:25:21 mcalabre Exp mcalabre $
 *=============================================================================
 * Usage: fitshdr [infile]
 *-----------------------------------------------------------------------------
@@ -44,7 +43,7 @@ char usage[] =
 "  -q N         Quit after reading the Nth header, where N is an integer\n"
 "               (optional space between -q and N).\n";
 
-/* Get LFS definitions for stdio.h. */
+// Get LFS definitions for stdio.h.
 #include <wcsconfig_utils.h>
 
 #include <errno.h>
@@ -72,7 +71,7 @@ int main(int argc, char **argv)
   unsigned long long int iblock = 0, nblock = 0, nbyte;
   struct stat instat;
 
-  /* Parse options. */
+  // Parse options.
   for (i = 1; i < argc && argv[i][0] == '-'; i++) {
     switch (argv[i][1]) {
     case 'q':
@@ -91,8 +90,8 @@ int main(int argc, char **argv)
     }
   }
 
-  /* If an input file name was specified then reopen it as stdin */
-  /* (doesn't affect seekability).                               */
+  // If an input file name was specified then reopen it as stdin
+  // (doesn't affect seekability).
   if (i < argc) {
     if (access(argv[i], R_OK) == -1) {
       perror(argv[i]);
@@ -105,7 +104,7 @@ int main(int argc, char **argv)
     }
   }
 
-  /* Check for standard FITS or RPFITS. */
+  // Check for standard FITS or RPFITS.
   if (!fread(cbuff, (size_t)80, (size_t)1, stdin)) {
     perror(argv[i]);
     return 2;
@@ -117,25 +116,25 @@ int main(int argc, char **argv)
       return 2;
     }
 
-    /* Assume FITS by default. */
+    // Assume FITS by default.
     format = rpfits + 2;
     blksiz = 2880;
 
-    /* Check for RPFITS. */
+    // Check for RPFITS.
     if (strncmp(cbuff+80, "FORMAT  =               RPFITS", 30) == 0 ||
         strncmp(cbuff+80, "FORMAT  =             'RPFITS'", 30) == 0) {
       if (strcmp(*argv, "rpfhdr") == 0) {
-        /* If invoked as 'rpfhdr' then allow RPFITS. */
+        // If invoked as 'rpfhdr' then allow RPFITS.
         format = rpfits;
         blksiz = 2560;
       } else {
-        /* Otherwise disallow RPFITS but issue a warning. */
+        // Otherwise disallow RPFITS but issue a warning.
         printf("WARNING: Input appears to be RPFITS, continuing anyway using "
           "2880-byte blocks.\n" );
       }
     }
 
-    /* Read the rest of the first block. */
+    // Read the rest of the first block.
     if (!fread(cbuff+160, (size_t)(blksiz-160), (size_t)1, stdin)) {
       perror(argv[i]);
       return 2;
@@ -144,13 +143,13 @@ int main(int argc, char **argv)
     inhdr = 1;
 
   } else {
-    /* If we have not been invoked as 'rpfhdr' then bail out now. */
+    // If we have not been invoked as 'rpfhdr' then bail out now.
     if (strcmp(*argv, "rpfhdr") != 0) {
       fprintf(stderr, "Input file does not appear to be standard FITS.\n" );
       return 1;
     }
 
-    /* RPFITS may have a block or two of rubbish before the first header. */
+    // RPFITS may have a block or two of rubbish before the first header.
     format = rpfits;
     blksiz = 2560;
 
@@ -188,15 +187,15 @@ int main(int argc, char **argv)
     format, ++ihdr, ++iblock, dashes);
 
 
-  /* Scan through the file. */
+  // Scan through the file.
   while (1) {
     if (!inhdr) {
-      /* Searching for a header. */
+      // Searching for a header.
       if (!fread(cbuff, (size_t)10, (size_t)1, stdin)) break;
 
       if (strncmp(cbuff, "SIMPLE  = ", 10) == 0 ||
           strncmp(cbuff, "XTENSION= ", 10) == 0) {
-        /* Found a header. */
+        // Found a header.
         if (iblock) {
           nbyte = blksiz * nblock;
           printf("Skipped %lld block%s of data of size %d bytes (%lld "
@@ -211,7 +210,7 @@ int main(int argc, char **argv)
         nblock = 0;
 
       } else {
-        /* Seek past it if possible. */
+        // Seek past it if possible.
         if (seekable) {
 #ifdef HAVE_FSEEKO
           if (fseeko(stdin, (off_t)(blksiz-10), SEEK_CUR)) {
@@ -236,13 +235,13 @@ int main(int argc, char **argv)
 
     if (inhdr) {
       for (cptr = cbuff; cptr < cbuff + blksiz; cptr += 80) {
-        /* Write out a keyrecord without trailing blanks. */
+        // Write out a keyrecord without trailing blanks.
         for (len = 80; len > 0; len--) {
           if (cptr[len-1] != ' ') break;
         }
         printf("%.*s\n", len, cptr);
 
-        /* Check for end-of-header. */
+        // Check for end-of-header.
         if (strncmp(cptr, "END     ", 8) == 0) {
           inhdr = 0;
           printf("%s\n", dashes);
@@ -251,7 +250,7 @@ int main(int argc, char **argv)
         }
       }
 
-      /* Get the next header block. */
+      // Get the next header block.
       if (inhdr) {
         if (!fread(cbuff, (size_t)blksiz, (size_t)1, stdin)) break;
         iblock++;
@@ -272,7 +271,7 @@ int main(int argc, char **argv)
       nblock++;
 
       if (nblock%1000 == 0) {
-        /* Report progress on stderr in case it's saved to file. */
+        // Report progress on stderr in case it's saved to file.
         nbyte = blksiz * nblock;
         fprintf(stderr, "Skipping %lld blocks of data of size %d bytes "
           "(%lld bytes).   \r", nblock, blksiz, nbyte);
