@@ -1,6 +1,5 @@
 /*============================================================================
-
-  WCSLIB 7.1 - an implementation of the FITS WCS standard.
+  WCSLIB 7.3 - an implementation of the FITS WCS standard.
   Copyright (C) 1995-2020, Mark Calabretta
 
   This file is part of WCSLIB.
@@ -22,7 +21,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcsgrid.c,v 7.1 2019/12/31 13:25:20 mcalabre Exp $
+  $Id: wcsgrid.c,v 7.3.1.2 2020/08/17 11:25:21 mcalabre Exp mcalabre $
 *=============================================================================
 *
 * wcsgrid extracts the WCS keywords for an image from the specified FITS file
@@ -82,7 +81,7 @@ int main(int argc, char **argv)
   fitsfile *fptr;
 
 
-  /* Parse options. */
+  // Parse options.
   strcpy(pgdev, "/XWINDOW");
   for (i = 1; i < argc && argv[i][0] == '-'; i++) {
     if (!argv[i][1]) break;
@@ -128,14 +127,14 @@ int main(int argc, char **argv)
     infile = "-";
   }
 
-  /* Check accessibility of the input file. */
+  // Check accessibility of the input file.
   if (strcmp(infile, "-") && access(infile, R_OK) == -1) {
     printf("wcsgrid: Cannot access %s.\n", infile);
     return 1;
   }
 
 
-  /* Open the FITS file and move to the required HDU. */
+  // Open the FITS file and move to the required HDU.
   status = 0;
   if (fits_open_file(&fptr, infile, READONLY, &status)) goto fitserr;
   if (fits_movabs_hdu(fptr, hdunum, &hdutype, &status)) goto fitserr;
@@ -145,7 +144,7 @@ int main(int argc, char **argv)
     return 1;
   }
 
-  /* Check that we have at least two image axes. */
+  // Check that we have at least two image axes.
   if (fits_read_key(fptr, TINT, "NAXIS",  &naxes, NULL, &status)) {
     goto fitserr;
   }
@@ -158,13 +157,13 @@ int main(int argc, char **argv)
     printf("HDU number %d contains a %d-D image array.\n", hdunum, naxes);
   }
 
-  /* Read in the FITS header, excluding COMMENT and HISTORY keyrecords. */
+  // Read in the FITS header, excluding COMMENT and HISTORY keyrecords.
   if (fits_hdr2str(fptr, 1, NULL, 0, &header, &nkeyrec, &status)) {
     goto fitserr;
   }
 
 
-  /* Interpret the WCS keywords. */
+  // Interpret the WCS keywords.
   if ((status = wcspih(header, nkeyrec, WCSHDR_all, -3, &nreject, &nwcs,
                        &wcs))) {
     fprintf(stderr, "wcspih ERROR %d: %s.\n", status, wcshdr_errmsg[status]);
@@ -172,12 +171,12 @@ int main(int argc, char **argv)
   }
   free(header);
 
-  /* Read -TAB arrays from the binary table extension (if necessary). */
+  // Read -TAB arrays from the binary table extension (if necessary).
   if (fits_read_wcstab(fptr, wcs->nwtb, (wtbarr *)wcs->wtb, &status)) {
     goto fitserr;
   }
 
-  /* Translate non-standard WCS keyvalues. */
+  // Translate non-standard WCS keyvalues.
   if ((status = wcsfix(7, 0, wcs, stat))) {
     status = 0;
     for (i = 0; i < NWCSFIX; i++) {
@@ -185,7 +184,7 @@ int main(int argc, char **argv)
          fprintf(stderr, "wcsfix ERROR %d: %s.\n", stat[i],
                  wcsfix_errmsg[stat[i]]);
 
-        /* Ignore problems with CDi_ja and DATE-OBS. */
+        // Ignore problems with CDi_ja and DATE-OBS.
         if (!(i == CDFIX || i == DATFIX)) status = 1;
       }
     }
@@ -193,7 +192,7 @@ int main(int argc, char **argv)
     if (status) return 1;
   }
 
-  /* Sort out alternates. */
+  // Sort out alternates.
   if (alt) {
     wcsidx(nwcs, &wcs, alts);
 
@@ -218,7 +217,7 @@ int main(int argc, char **argv)
     }
   }
 
-  /* Get image dimensions from the header. */
+  // Get image dimensions from the header.
   sprintf(keyword, "NAXIS%d", wcs->lng + 1);
   fits_read_key(fptr, TINT, "NAXIS1", naxis,   NULL, &status);
   sprintf(keyword, "NAXIS%d", wcs->lat + 1);
@@ -233,7 +232,7 @@ int main(int argc, char **argv)
   fits_close_file(fptr, &status);
 
 
-  /* Plot setup. */
+  // Plot setup.
   blc[0] = 0.5f;
   blc[1] = 0.5f;
   trc[0] = naxis[0] + 0.5f;
@@ -249,16 +248,16 @@ int main(int argc, char **argv)
   cpgask(1);
   cpgpage();
 
-  /* Compact lettering. */
+  // Compact lettering.
   cpgsch(0.8f);
 
-  /* Draw full grid lines. */
+  // Draw full grid lines.
   gcode[0] = 2;
   gcode[1] = 2;
   grid1[0] =    0.0;
   grid2[0] =    0.0;
 
-  /* These are for the projection boundary. */
+  // These are for the projection boundary.
   grid1[1] = -180.0;
   grid1[2] =  180.0;
   grid2[1] =  -90.0;
@@ -276,10 +275,10 @@ int main(int argc, char **argv)
       continue;
     }
 
-    /* Draw the frame. */
+    // Draw the frame.
     cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
-    /* Axis labels; use CNAMEia in preference to CTYPEia. */
+    // Axis labels; use CNAMEia in preference to CTYPEia.
     if ((wcs+i)->cname[0][0]) {
       strcpy(idents[0], (wcs+i)->cname[0]);
     } else {
@@ -292,33 +291,33 @@ int main(int argc, char **argv)
       strcpy(idents[1], (wcs+i)->ctype[1]);
     }
 
-    /* Title; use WCSNAME. */
+    // Title; use WCSNAME.
     strcpy(idents[2], (wcs+i)->wcsname);
     if (strlen(idents[2])) {
       printf("\n%s\n", idents[2]);
     }
 
-    /* Formatting control for celestial coordinates. */
+    // Formatting control for celestial coordinates.
     if (strncmp((wcs+i)->ctype[0], "RA", 2) == 0) {
-      /* Right ascension in HMS, declination in DMS. */
+      // Right ascension in HMS, declination in DMS.
       opt[0] = 'G';
       opt[1] = 'E';
     } else {
-      /* Other angles in decimal degrees. */
+      // Other angles in decimal degrees.
       opt[0] = 'A';
       opt[1] = 'B';
     }
 
-    /* Draw the celestial grid.  The grid density is set for each world */
-    /* coordinate by specifying LABDEN = 1224. */
+    // Draw the celestial grid.  The grid density is set for each world
+    // coordinate by specifying LABDEN = 1224.
     ic = -1;
     cpgsbox(blc, trc, idents, opt, 0, 1224, c0, gcode, 0.0, 0, grid1, 0,
       grid2, 0, pgwcsl_, 1, WCSLEN, 1, nlcprm, (int *)(wcs+i), nldprm, 256,
       &ic, cache, &status);
 
-    /* Delimit the projection boundary. */
+    // Delimit the projection boundary.
     if ((wcs+i)->cel.prj.category != ZENITHAL) {
-      /* Reset to the native coordinate graticule. */
+      // Reset to the native coordinate graticule.
       (wcs+i)->crval[0] = (wcs+i)->cel.prj.phi0;
       (wcs+i)->crval[1] = (wcs+i)->cel.prj.theta0;
       (wcs+i)->lonpole  = 999.0;
