@@ -1,6 +1,5 @@
 /*============================================================================
-
-  WCSLIB 7.1 - an implementation of the FITS WCS standard.
+  WCSLIB 7.3 - an implementation of the FITS WCS standard.
   Copyright (C) 1995-2020, Mark Calabretta
 
   This file is part of WCSLIB.
@@ -22,7 +21,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcsware.c,v 7.1 2019/12/31 13:25:20 mcalabre Exp $
+  $Id: wcsware.c,v 7.3.1.2 2020/08/17 11:25:21 mcalabre Exp mcalabre $
 *=============================================================================
 * wcsware extracts the WCS keywords for an image from the specified FITS file,
 * constructs wcsprm structs for each coordinate representation found and
@@ -99,7 +98,7 @@ int main(int argc, char **argv)
   struct wcsprm *wcs, *wcsi = 0x0;
   fitsfile *fptr;
 
-  /* Initialise control variables. */
+  // Initialise control variables.
   allimg =  0;
   ctrl   = -3;
   dobth  =  0;
@@ -113,40 +112,40 @@ int main(int argc, char **argv)
   relax  = WCSHDR_all;
   strict =  0;
 
-  /* Parse options. */
+  // Parse options.
   for (i = 1; i < argc && argv[i][0] == '-'; i++) {
     if (!argv[i][1]) break;
 
     switch (argv[i][1]) {
     case 'a':
-      /* Select an alternate WCS. */
+      // Select an alternate WCS.
       alt = argv[i]+2;
       break;
 
     case 'b':
-      /* Use wcsbth() for image headers. */
+      // Use wcsbth() for image headers.
       dobth  = 1;
       allimg = 1;
       break;
 
     case 'f':
-      /* Apply wcsfix(). */
+      // Apply wcsfix().
       dofix  = 1;
       break;
 
     case 'h':
-      /* Move to HDU number. */
+      // Move to HDU number.
       hdunum = atoi(argv[i]+2);
       if (hdunum < 0) hdunum = 0;
       break;
 
     case 'i':
-      /* Allow image header keywords in bintables. */
+      // Allow image header keywords in bintables.
       allimg = 1;
       break;
 
     case 'l':
-      /* Lint. */
+      // Lint.
       strict = 1;
       relax  = WCSHDR_strict;
       ctrl   = 3;
@@ -154,39 +153,39 @@ int main(int argc, char **argv)
       break;
 
     case 'o':
-      /* Print header using wcshdo(). */
+      // Print header using wcshdo().
       dohdr = 1;
       break;
 
     case 'p':
-      /* Print structs. */
+      // Print structs.
       doprt  = 1;
       break;
 
     case 'P':
-      /* Print non-default structs. */
+      // Print non-default structs.
       doprt  = -1;
       break;
 
     case 'r':
-      /* Strict, but allow some deprecated usage. */
+      // Strict, but allow some deprecated usage.
       strict = 0;
       relax  = WCSHDR_reject;
       break;
 
     case 's':
-      /* Strict, really strict. */
+      // Strict, really strict.
       strict = 1;
       relax  = WCSHDR_strict;
       break;
 
     case 't':
-      /* Terse. */
+      // Terse.
       ctrl   = 2;
       break;
 
     case 'v':
-      /* Verbose. */
+      // Verbose.
       ctrl   = 4;
       break;
 
@@ -222,7 +221,7 @@ int main(int argc, char **argv)
   if (!(dolint || dohdr || doprt || dopix || dowrld)) doprt = 1;
 
 
-  /* Open the FITS file and move to the required HDU. */
+  // Open the FITS file and move to the required HDU.
   status = 0;
   if (fits_open_file(&fptr, infile, READONLY, &status)) goto fitserr;
   if (hdunum) {
@@ -231,13 +230,13 @@ int main(int argc, char **argv)
     if (fits_get_hdu_type(fptr, &hdutype, &status)) goto fitserr;
   }
 
-  /* Read in the FITS header, excluding COMMENT and HISTORY keyrecords. */
+  // Read in the FITS header, excluding COMMENT and HISTORY keyrecords.
   if (fits_hdr2str(fptr, 1, NULL, 0, &header, &nkeyrec, &status)) {
     goto fitserr;
   }
 
 
-  /* Interpret the WCS keywords. */
+  // Interpret the WCS keywords.
   if ((hdutype == BINARY_TBL) ||
      ((hdutype == IMAGE_HDU) && dobth)) {
     keysel = (hdutype == BINARY_TBL) ? 0 : WCSHDR_IMGHEAD;
@@ -278,7 +277,7 @@ int main(int argc, char **argv)
   }
 
 
-  /* Sort out alternates. */
+  // Sort out alternates.
   if (alt) {
     i = 0;
 
@@ -323,7 +322,7 @@ int main(int argc, char **argv)
   }
 
 
-  /* Initialize and possibly print the structs. */
+  // Initialize and possibly print the structs.
   wcserr_enable(1);
   wcsprintf_set(stdout);
 
@@ -336,13 +335,13 @@ int main(int argc, char **argv)
       wcsprintf("\n");
     }
 
-    /* Read -TAB arrays from the binary table extension (if necessary). */
+    // Read -TAB arrays from the binary table extension (if necessary).
     if (fits_read_wcstab(fptr, wcs[i].nwtb, (wtbarr *)wcs[i].wtb,
                          &status)) {
       goto fitserr;
     }
 
-    /* Translate non-standard WCS keyvalues? */
+    // Translate non-standard WCS keyvalues?
     if (dofix) {
       stat = malloc(NWCSFIX * sizeof(int));
       if ((status = wcsfix(7, 0, wcs+i, stat))) {
@@ -362,10 +361,10 @@ int main(int argc, char **argv)
       continue;
     }
 
-    /* Get WCSNAME out of the wcsprm struct. */
+    // Get WCSNAME out of the wcsprm struct.
     strcpy(wcsname, wcs[i].wcsname);
 
-    /* Print the struct as a FITS header. */
+    // Print the struct as a FITS header.
     if (dohdr) {
       if (wcshdo(WCSHDO_all, wcs+i, &nkeyrec, &header)) {
         wcsperr(wcs+i, "");
@@ -381,7 +380,7 @@ int main(int argc, char **argv)
       free(header);
     }
 
-    /* Print the struct. */
+    // Print the struct.
     if (doprt) {
       if (doprt == 1 || strcmp(wcsname, "DEFAULTS")) {
         if (strlen(wcsname)) {
@@ -393,7 +392,7 @@ int main(int argc, char **argv)
       }
     }
 
-    /* Transform coordinates? */
+    // Transform coordinates?
     if (dopix || dowrld) {
       if (strlen(wcsname)) {
         wcsprintf("\n%s\n", wcsname);
@@ -406,7 +405,7 @@ int main(int argc, char **argv)
       stat   = realloc(stat,   nelem * sizeof(int));
 
       if (dopix) {
-        /* Transform pixel coordinates. */
+        // Transform pixel coordinates.
         while (1) {
           wcsprintf("\nEnter %d pixel coordinate element%s: ", nelem,
             (nelem==1)?"":"s");
@@ -446,7 +445,7 @@ int main(int argc, char **argv)
             wcsprintf("\nImage: ");
             for (j = 0; j < nelem; j++) {
               if (j == wcs[i].lng || j == wcs[i].lat) {
-                /* Print angles in fixed format. */
+                // Print angles in fixed format.
                 wcsprintf("%s%14.6f", j?", ":"", imgcrd[j]);
               } else {
                 wcsprintf("%s%14.9g", j?", ":"", imgcrd[j]);
@@ -456,7 +455,7 @@ int main(int argc, char **argv)
             wcsprintf("\nWorld: ");
             for (j = 0; j < nelem; j++) {
               if (j == wcs[i].lng || j == wcs[i].lat) {
-                /* Print angles in fixed format. */
+                // Print angles in fixed format.
                 wcsprintf("%s%14.6f", j?", ":"", world[j]);
               } else {
                 wcsprintf("%s%14.9g", j?", ":"", world[j]);
@@ -469,7 +468,7 @@ int main(int argc, char **argv)
 
 
       if (dowrld) {
-        /* Transform world coordinates. */
+        // Transform world coordinates.
         while (1) {
           wcsprintf("\nEnter %d world coordinate element%s: ", nelem,
             (nelem==1)?"":"s");
@@ -499,7 +498,7 @@ int main(int argc, char **argv)
           wcsprintf("World: ");
           for (j = 0; j < nelem; j++) {
             if (j == wcs[i].lng || j == wcs[i].lat) {
-              /* Print angles in fixed format. */
+              // Print angles in fixed format.
               wcsprintf("%s%14.6f", j?", ":"", world[j]);
             } else {
               wcsprintf("%s%14.9g", j?", ":"", world[j]);
@@ -514,7 +513,7 @@ int main(int argc, char **argv)
             wcsprintf("\nImage: ");
             for (j = 0; j < nelem; j++) {
               if (j == wcs[i].lng || j == wcs[i].lat) {
-                /* Print angles in fixed format. */
+                // Print angles in fixed format.
                 wcsprintf("%s%14.6f", j?", ":"", imgcrd[j]);
               } else {
                 wcsprintf("%s%14.9g", j?", ":"", imgcrd[j]);
@@ -534,7 +533,7 @@ int main(int argc, char **argv)
 
   fits_close_file(fptr, &status);
 
-  /* Defeat spurious reporting of memory leaks. */
+  // Defeat spurious reporting of memory leaks.
   wcsvfree(&nwcs, &wcs);
   free(world);
   free(imgcrd);
